@@ -354,6 +354,8 @@ from ansible.module_utils.common.respawn import has_respawned, probe_interpreter
 from ansible.module_utils.yumdnf import YumDnf, yumdnf_argument_spec
 
 libdnf5 = None
+# Through dnf5-5.2.12 all exceptions raised through swig became RuntimeError
+LIBDNF5_ERROR = RuntimeError
 
 
 def is_installed(base, spec):
@@ -411,7 +413,7 @@ def is_newer_version_installed(base, spec):
 
     try:
         spec_nevra = next(iter(libdnf5.rpm.Nevra.parse(spec)))
-    except (RuntimeError, StopIteration):
+    except (LIBDNF5_ERROR, StopIteration):
         return False
 
     spec_version = spec_nevra.get_version()
@@ -503,12 +505,19 @@ class Dnf5Module(YumDnf):
         os.environ["LANGUAGE"] = os.environ["LANG"] = locale
 
         global libdnf5
+        global LIBDNF5_ERROR
         has_dnf = True
         try:
             import libdnf5  # type: ignore[import]
         except ImportError:
             has_dnf = False
 
+        try:
+            import libdnf5.exception  # type: ignore[import-not-found]
+            LIBDNF5_ERROR = libdnf5.exception.Error
+        except (ImportError, AttributeError):
+            pass
+
         if has_dnf:
             return
 
@@ -553,7 +562,7 @@ class Dnf5Module(YumDnf):
 
         try:
             base.load_config()
-        except RuntimeError as e:
+        except LIBDNF5_ERROR as e:
             self.module.fail_json(
                 msg=str(e),
                 conf_file=self.conf_file,
@@ -692,6 +701,7 @@ class Dnf5Module(YumDnf):
             if self.security:
                 types.append("security")
             advisory_query.filter_type(types)
+            conf.skip_unavailable = True  # ignore packages that are of a different type, for backwards compat
             settings.set_advisory_filter(advisory_query)
 
         goal = libdnf5.base.Goal(base)
@@ -716,7 +726,7 @@ class Dnf5Module(YumDnf):
             for spec in self.names:
                 try:
                     goal.add_remove(spec, settings)
-                except RuntimeError as e:
+                except LIBDNF5_ERROR as e:
                     self.module.fail_json(msg=str(e), failures=[], rc=1)
             if self.autoremove:
                 for pkg in get_unneeded_pkgs(base):
@@ -725,7 +735,7 @@ class Dnf5Module(YumDnf):
         goal.set_allow_erasing(self.allowerasing)
         try:
             transaction = goal.resolve()
-        except RuntimeError as e:
+        except LIBDNF5_ERROR as e:
             self.module.fail_json(msg=str(e), failures=[], rc=1)
 
         if transaction.get_problems():
@@ -767,7 +777,7 @@ class Dnf5Module(YumDnf):
         if self.module.check_mode:
             if results:
                 msg = "Check mode: No changes made, but would have if not in check mode"
-        else:
+        elif changed:
             transaction.download()
             if not self.download_only:
                 transaction.set_description("ansible dnf5 module")
