@@ -3,8 +3,7 @@
 # Copyright: (c) 2012, Michael DeHaan <michael.dehaan@gmail.com>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 DOCUMENTATION = r'''
@@ -36,8 +35,8 @@ options:
             commands unless necessary.
           - V(restarted) will always bounce the service.
           - V(reloaded) will always reload.
-          - B(At least one of state and enabled are required.)
-          - Note that reloaded will start the service if it is not already started,
+          - At least one of O(state) and O(enabled) are required.
+          - Note that V(reloaded) will start the service if it is not already started,
             even if your chosen init system wouldn't normally.
         type: str
         choices: [ reloaded, restarted, started, stopped ]
@@ -53,7 +52,7 @@ options:
     pattern:
         description:
         - If the service does not respond to the status command, name a
-          substring to look for as would be found in the output of the I(ps)
+          substring to look for as would be found in the output of the C(ps)
           command as a stand-in for a status result.
         - If the string is found, the service will be assumed to be started.
         - While using remote hosts with systemd this setting will be ignored.
@@ -62,7 +61,7 @@ options:
     enabled:
         description:
         - Whether the service should start on boot.
-        - B(At least one of state and enabled are required.)
+        - At least one of O(state) and O(enabled) are required.
         type: bool
     runlevel:
         description:
@@ -81,7 +80,7 @@ options:
     use:
         description:
         - The service module actually uses system specific modules, normally through auto detection, this setting can force a specific module.
-        - Normally it uses the value of the 'ansible_service_mgr' fact and falls back to the old 'service' module when none matching is found.
+        - Normally it uses the value of the C(ansible_service_mgr) fact and falls back to the C(ansible.legacy.service) module when none matching is found.
         - The 'old service module' still uses autodetection and in no way does it correspond to the C(service) command.
         type: str
         default: auto
@@ -180,7 +179,7 @@ from ansible.module_utils.common.text.converters import to_bytes, to_text
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.common.locale import get_best_parsable_locale
 from ansible.module_utils.common.sys_info import get_platform_subclass
-from ansible.module_utils.service import fail_if_missing
+from ansible.module_utils.service import fail_if_missing, is_systemd_managed
 from ansible.module_utils.six import PY2, b
 
 
@@ -485,24 +484,7 @@ class LinuxService(Service):
 
             # tools must be installed
             if location.get('systemctl', False):
-
-                # this should show if systemd is the boot init system
-                # these mirror systemd's own sd_boot test http://www.freedesktop.org/software/systemd/man/sd_booted.html
-                for canary in ["/run/systemd/system/", "/dev/.run/systemd/", "/dev/.systemd/"]:
-                    if os.path.exists(canary):
-                        return True
-
-                # If all else fails, check if init is the systemd command, using comm as cmdline could be symlink
-                try:
-                    f = open('/proc/1/comm', 'r')
-                except IOError:
-                    # If comm doesn't exist, old kernel, no systemd
-                    return False
-
-                for line in f:
-                    if 'systemd' in line:
-                        return True
-
+                return is_systemd_managed(self.module)
             return False
 
         # Locate a tool to enable/disable a service
@@ -1030,7 +1012,7 @@ class FreeBsdService(Service):
         self.sysrc_cmd = self.module.get_bin_path('sysrc')
 
     def get_service_status(self):
-        rc, stdout, stderr = self.execute_command("%s %s %s %s" % (self.svc_cmd, self.name, 'onestatus', self.arguments))
+        rc, stdout, stderr = self.execute_command("%s %s %s %s" % (self.svc_cmd, self.arguments, self.name, 'onestatus'))
         if self.name == "pf":
             self.running = "Enabled" in stdout
         else:
@@ -1050,7 +1032,7 @@ class FreeBsdService(Service):
             if os.path.isfile(rcfile):
                 self.rcconf_file = rcfile
 
-        rc, stdout, stderr = self.execute_command("%s %s %s %s" % (self.svc_cmd, self.name, 'rcvar', self.arguments))
+        rc, stdout, stderr = self.execute_command("%s %s %s %s" % (self.svc_cmd, self.arguments, self.name, 'rcvar'))
         try:
             rcvars = shlex.split(stdout, comments=True)
         except Exception:
@@ -1115,7 +1097,7 @@ class FreeBsdService(Service):
         if self.action == "reload":
             self.action = "onereload"
 
-        ret = self.execute_command("%s %s %s %s" % (self.svc_cmd, self.name, self.action, self.arguments))
+        ret = self.execute_command("%s %s %s %s" % (self.svc_cmd, self.arguments, self.name, self.action))
 
         if self.sleep:
             time.sleep(self.sleep)
