@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
 # Copyright: (c) , Ansible Project
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 
-# WARNING: this is mostly here as a convinence for documenting core behaviours, no plugin outside of ansbile-core should use this file
+# WARNING: this is mostly here as a convenience for documenting core behaviours, no plugin outside of ansible-core should use this file
 class ModuleDocFragment(object):
 
     # requires action_common
@@ -29,8 +28,8 @@ attributes:
       support: full
       platforms: all
     until:
-      description: Denotes if this action objeys until/retry/poll keywords
-      support: full
+      description: Denotes if this action obeys until/retry/poll keywords
+      support: none
     tags:
       description: Allows for the 'tags' keyword to control the selection of this action for execution
       support: full
