@@ -29,15 +29,15 @@ class ModuleDocFragment(object):
       pretty_results:
         name: Configure output for readability
         description:
-          - Configure the result format to be more readable
-          - When O(result_format) is set to V(yaml) this option defaults to V(True), and defaults
-            to V(False) when configured to V(json).
-          - Setting this option to V(True) will force V(json) and V(yaml) results to always be pretty
+          - Configure the result format to be more readable.
+          - When O(result_format) is set to V(yaml) this option defaults to V(true), and defaults
+            to V(false) when configured to V(json).
+          - Setting this option to V(true) will force V(json) and V(yaml) results to always be pretty
             printed regardless of verbosity.
-          - When set to V(True) and used with the V(yaml) result format, this option will
+          - When set to V(true) and used with the V(yaml) result format, this option will
             modify module responses in an attempt to produce a more human friendly output at the expense
             of correctness, and should not be relied upon to aid in writing variable manipulations
-            or conditionals. For correctness, set this option to V(False) or set O(result_format) to V(json).
+            or conditionals. For correctness, set this option to V(false) or set O(result_format) to V(json).
         type: bool
         default: null
         env:
