@@ -20,6 +20,8 @@ from .util import (
     SubprocessError,
     cache,
     OutputStream,
+    InternalError,
+    format_command_output,
 )
 
 from .util_common import (
@@ -47,7 +49,7 @@ DOCKER_COMMANDS = [
     'podman',
 ]
 
-UTILITY_IMAGE = 'quay.io/ansible/ansible-test-utility-container:2.0.0'
+UTILITY_IMAGE = 'quay.io/ansible/ansible-test-utility-container:3.1.0'
 
 # Max number of open files in a docker container.
 # Passed with --ulimit option to the docker run command.
@@ -300,7 +302,7 @@ def detect_host_properties(args: CommonConfig) -> ContainerHostProperties:
     options = ['--volume', '/sys/fs/cgroup:/probe:ro']
     cmd = ['sh', '-c', ' && echo "-" && '.join(multi_line_commands)]
 
-    stdout = run_utility_container(args, 'ansible-test-probe', cmd, options)[0]
+    stdout, stderr = run_utility_container(args, 'ansible-test-probe', cmd, options)
 
     if args.explain:
         return ContainerHostProperties(
@@ -313,6 +315,12 @@ def detect_host_properties(args: CommonConfig) -> ContainerHostProperties:
 
     blocks = stdout.split('\n-\n')
 
+    if len(blocks) != len(multi_line_commands):
+        message = f'Unexpected probe output. Expected {len(multi_line_commands)} blocks but found {len(blocks)}.\n'
+        message += format_command_output(stdout, stderr)
+
+        raise InternalError(message.strip())
+
     values = blocks[0].split('\n')
 
     audit_parts = values[0].split(' ', 1)
@@ -713,9 +721,10 @@ def docker_rm(args: CommonConfig, container_id: str) -> None:
     """Remove the specified container."""
     try:
         # Stop the container with SIGKILL immediately, then remove the container.
-        # Podman supports the `--time` option on `rm`, but only since version 4.0.0.
-        # Docker does not support the `--time` option on `rm`.
-        docker_command(args, ['stop', '--time', '0', container_id], capture=True)
+        # Docker supports `--timeout` for stop. The `--time` option was deprecated in v28.0.
+        # Podman supports `--time` for stop. The `--timeout` option was deprecated in 1.9.0.
+        # Both Docker and Podman support the `-t` option for stop.
+        docker_command(args, ['stop', '-t', '0', container_id], capture=True)
         docker_command(args, ['rm', container_id], capture=True)
     except SubprocessError as ex:
         # Both Podman and Docker report an error if the container does not exist.
